@@ -32,6 +32,7 @@
 #ifdef HILDON_HAS_APP_MENU
 #include <hildon/hildon-text-view.h>
 #include <hildon/hildon-pannable-area.h>
+#include <hildon/hildon-gtk.h>
 #endif
 
 #include "callbacks.h"
@@ -102,14 +103,17 @@ on_orientation_changed(GdkScreen *screen, GHashTable *hash)
 
 	GtkWidget *toolbar = g_hash_table_lookup(hash, "toolbar");
 	GtkWidget *menu_open = g_hash_table_lookup(hash, "menu_open");
+	GtkWidget *menu_settings = g_hash_table_lookup(hash, "menu_settings");
 
 	app_data->portrait = is_portrait_mode();
 
 	if (app_data->portrait) {
 		gtk_widget_hide(toolbar);
+		gtk_widget_hide(menu_settings);
 		gtk_widget_show(menu_open);
 	} else {
 		gtk_widget_show(toolbar);
+		gtk_widget_show(menu_settings);
 		gtk_widget_hide(menu_open);
 	}
 }
@@ -797,6 +801,7 @@ GtkWidget* create_mainwin(Note *note) {
 	g_hash_table_insert(hash, "toolbar", toolbar);
 	g_hash_table_insert(hash, "menu_new", menu_new);
 	g_hash_table_insert(hash, "menu_open", menu_open);
+	g_hash_table_insert(hash, "menu_settings", menu_settings);
 	g_signal_connect((gpointer)screen, "size-changed",
 			G_CALLBACK(on_orientation_changed),
 			hash);
@@ -806,6 +811,9 @@ GtkWidget* create_mainwin(Note *note) {
 			G_CALLBACK (on_link_internal_tag_event),
 			note);
 
+#ifdef HILDON_HAS_APP_MENU
+	hildon_gtk_window_set_portrait_flags(GTK_WINDOW(mainwin), HILDON_PORTRAIT_MODE_SUPPORT);
+#endif
 
 	return mainwin;
 }
